<div align="center"><p>
    <h1>CYBERONIX</h1>
    <img style="filter: brightness(200%)" src="https://user-images.githubusercontent.com/122822828/216810369-34904b5a-d063-48a9-a87d-11caf293243b.png" width="50%"><br>
    <img src="https://forthebadge.com/images/badges/made-with-python.svg">
    <img src="https://forthebadge.com/images/badges/built-with-love.svg">
    <br><br>
    <a href="https://github.com/TeamMetaxone/Cyberonix/releases/latest">
      <img alt="Latest release" src="https://img.shields.io/github/v/release/TeamMetaxone/Cyberonix?style=for-the-badge&logo=starship&color=C9CBFF&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/TeamMetaxone/Cyberonix/pulse">
      <img alt="Last commit" src="https://img.shields.io/github/last-commit/TeamMetaxone/Cyberonix?style=for-the-badge&logo=starship&color=8bd5ca&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/TeamMetaxone/Cyberonix/blob/main/LICENSE">
      <img alt="License" src="https://img.shields.io/github/license/TeamMetaxone/Cyberonix?style=for-the-badge&logo=starship&color=ee999f&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/TeamMetaxone/Cyberonix/stargazers">
      <img alt="Stars" src="https://img.shields.io/github/stars/TeamMetaxone/Cyberonix?style=for-the-badge&logo=starship&color=c69ff5&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/TeamMetaxone/Cyberonix/issues">
      <img alt="Issues" src="https://img.shields.io/github/issues/TeamMetaxone/Cyberonix?style=for-the-badge&logo=bilibili&color=F5E0DC&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/TeamMetaxone/Cyberonix">
        <img alt="Repo Size" src="https://img.shields.io/github/repo-size/TeamMetaxone/Cyberonix?color=%23DDB6F2&label=SIZE&logo=codesandbox&style=for-the-badge&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://twitter.com/intent/follow?screen_name=niteshlike123">
      <img alt="follow on Twitter" src="https://img.shields.io/twitter/follow/niteshlike123?style=for-the-badge&logo=twitter&color=8aadf3&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://discord.gg/aJF4rr3PdR">
      <img alt="Discord" src="https://img.shields.io/discord/1072407436348112896?style=for-the-badge&logo=starship&color=c69ff5&logoColor=D9E0EE&labelColor=302D41"/>
    </a>
  </p>
  <p align="center">
    <img src="https://stars.medv.io/TeamMetaxone/Cyberonix.svg", title="commits"/>
  </p>

<h1 align="left">Description</h1>

<p align="left">
    Cyberonix is an open source & free tool by Team Metaxone Solution. The tool at first is developed by a team of students as part of their Internship at Metaxone Solution after their Diploma in Cyber Security Training. </p>

<p align="left"> It is a complete resource hub for Cyber Security Community. Our aim is to make this tool an 1 stop solution for all the Hackers out there to get resources of various topics in Cyber Security. We will keep updating this tool & adding new & updated resources on the go.</p>

<p align="left"> Feel free to suggest any feature that you want to see in this tool, We will be happy to include that in our next update. 
</p>

    
---

**[<kbd> <br> Install <br> </kbd>][Install]** 
**[<kbd> <br> Categories <br> </kbd>][Categories]** 
**[<kbd> <br> ScreenShots <br> </kbd>][ScreenShots]** 
**[<kbd> <br> Contributors <br> </kbd>][Contributors]**

---

[Categories]: #Categories
[Install]: #Installation
[ScreenShots]: #ScreenShots
[Contributors]: #Contributors
</div>

# Installation

```shell script
sudo apt update -y && apt full-upgrade -y
git clone https://github.com/TeamMetaxone/Cyberonix.git
cd Cyberonix
chmod +x setup.py
sudo python3 setup.py
cyberonix
```

# Categories
- ## Tools
    - ### Information Gathring
        - `Nmap`
        - `Maltego`
        - `Dracnmap`
        - `Red_Hawk`
        - `Th3Inspector`
        - `Hping3`
        - `Arping`
        - `Netdiscover`
        - `Wafw00f`
    - ### Vulnerability Analysis
        - `Wpscan`
        - `Wapiti`
        - `Nmap`
        - `Legion`
        - `Nikto`
    - ### Web Application Analysis
        - `Burp Suite`
        - `Owasp Zap`
        - `Nikto`
        - `Wapiti`
        - `Nessus`
        - `Dirb`
        - `Skipfish`
        - `Nuclei`
    - ### Password Attacks
        - ### Brute Force Attacks
            - `Hashcat`
            - `John The Ripper`
            - `Hydra`
            - `Johnny`
            - `Crackstatiion`
            - `cyberchef`
        - ### Dicitionary Attacks
            - `Hashcat`
            - `John The Ripper`
            - `Hydra`
            - `Medusa`
            - `Nrack`
            - `Johnny`
            - `Crackstation`
            - `Cyberchef`
        - ### Rainbow Table Attacks
            - `Rainbowcrack`
            - `Ophcrack`
        - ### Wordlist Generator
            - `Social-Engineer`
            - `Hiddeneye`
            - `R3Bu5`
            - `Zphisher`
            - `Shellphish`
            - `Gophish`
        - ### Phishing Attacks
            - `Social-Engineer`
            - `Hiddeneye`
            - `R3Bu5`
            - `Zphisher`
            - `Shellphis`
            - `Gophish`
        - ### Keylogger Attacks
            - `Zlogger`
    - ### Wireless Attacks
        - `Kismet`
        - `Wifite`
        - `Fern Wifi Cracker`
        - `Aircrack-Ng`
        - `Fluxion`
        - `Wifiphisher`
        - `Bettercap`
    - ### Exploitation Tools
        - `Metasploit`
        - `Crackmapexec`
        - `Searchsploit`
        - `Beef`
        - `Routersploit`
        - `Sqlmap`
        - `Airmitage`
        - `Commix`
    - ### Sniffing And Spoofing
        - `Wireshark`
        - `Bettercap`
        - `Tcpdump`
        - `Arpspoof`
        - `Dsniff`
        - `Scapy`
        - `Netsniff-Ng`
        - `Macchanger`
        - `Responder`
        - `Airgeddon`
        - `Sharesniffer`
        - `Wifi-Pumpkin-3`
    - ### Post Exploitation
        - ### Privilege Escalation
            - `Metasploit-Framework`
            - `Linpeas`
            - `Sudo Killer`
            - `Berrot`
            - `Linux Exploit Suggester 2`
            - `Lse`
            - `Pspy`
            - `Bashark`
            - `Linux Private-I`
        - ### Maintain Access
            - `Metasploit-Framework`
            - `Shellter`
            - `Amber`
            - `Upx`
        - ### Clearing or Removing Tracks
            - `Metasploit-Framework`
            - `Covermyass`
    - ### Pentesting And Bug-Bounty
        - `Katana` 
        - `Gau` 
        - `Gobuster` 
        - `Waybackurls` 
        - `Httpx` 
        - `Httprobe` 
        - `Eyewitness` 
        - `Gowitness` 
- ## Cheatsheets
    - `Nmap Cheatsheet` 
    -  `Maltego Cheatsheet` 
    -  `Hping3 Cheatsheet` 
    -  `Netdiscover Cheatsheet` 
    -  `Wafw00F Cheatsheet` 
    -  `Metasploit-Framework Cheatsheet`
    -  `Wireshark Cheatsheet` 
    -  `Bettercap Cheatsheet` 
    -  `Tcpdump Cheatsheet` 
    -  `Scapy Cheatsheet` 
    -  `Responder Cheatsheet` 
    -  `Airgeddon Cheatsheet` 
    -  `Wpscan Cheatsheet` 
    -  `Wapiti Cheatsheet` 
    -  `Legion Cheatsheet` 
    -  `Nikto Cheatsheet` 
    -  `Burp Suite Cheatsheet` 
    -  `Owasp Zap Cheatsheet` 
    -  `Nessus Cheatsheet` 
    -  `Dirb Cheatsheet` 
    -  `Skipfish Cheatsheet` 
    -  `Nuclei Cheatsheet` 
    -  `Wifite Cheatsheet` 
    -  `Aircrack-Ng Cheatsheet`
- ## News
    - `Date Wise`
    
# ScreenShots
![Screenshot](https://user-images.githubusercontent.com/122822828/216786205-703c36f5-874d-4947-9ea7-a33e7dde1d5b.png)
---
![Screenshot](https://user-images.githubusercontent.com/122822828/216786208-428e03f6-f0c5-41b4-a2bf-009633bef6d5.png)

<h1 align="left">Socials</h1>

<p align="left">
<a href="https://github.com/TeamMetaxone"><img src="https://user-images.githubusercontent.com/696094/196835284-c52d4bd1-7034-439e-848b-47d4f2933dff.svg" width="64" height="64" alt="Github Logo"/></a> <img src="assets/misc/transparent.png" height="1" width="5"/> <a href="https://discord.gg/aJF4rr3PdR"><img src="https://user-images.githubusercontent.com/696094/196835282-f5c47d66-29b7-4210-9ee0-d9cdecde3559.svg" width="64" height="64" alt="Discord Logo"/></a> <img src="assets/misc/transparent.png" height="1" width="5"/> <a href="https://twitter.com/niteshlike123"><img src="https://user-images.githubusercontent.com/696094/196835281-52617611-ede6-40da-a4bc-8c5025622bbf.svg" width="64" height="64" alt="Twitter Logo"/></a> <img src="assets/misc/transparent.png" height="1" width="5"/>
</p>

<h1 align="left">Support</h1>

<p><a href="https://www.buymeacoffee.com/metaxone" target="_blank"> <img align="left" src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" height="50" width="210" alt="Buymeacoffee" /></a></p><br><br><br>
<p><a href="https://paypal.me/niteshsinghhacker" target="_blank"> <img align="left" src="https://raw.githubusercontent.com/andreostrovsky/donate-with-paypal/master/blue.svg" height="70" width="210" alt="Donate with paypal" /></a></p><br><br><br>
<p><a href="https://tools.apgy.in/upi/Nitesh+Singh/niteshkumar5@ybl/" target="_blank"> <img align="left" style="border-radius:8px" src="https://user-images.githubusercontent.com/122822828/216837693-3480fcd2-b4fc-40ff-94f8-c5d7d4b82ad5.png" height="50" width="210" alt="Donate with paypal" /></a></p><br><br>
<p><a href="https://razorpay.me/@technicalnavigator" target="_blank"> <img align="left" src="https://user-images.githubusercontent.com/122822828/216838288-a946ef91-f215-4286-926f-afa71d0c3760.png" height="50" width="210" alt="Donate with paypal" /></a></p><br><br>

<div align="center">
    <h1 id="Contributors">Thanks To All Contributors</h1>

<a href="https://github.com/TeamMetaxone/Cyberonix/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=TeamMetaxone/Cyberonix" />
</a>
</div>

[Contribute]: #Contributors
[Install]: #installation
[Troubleshoot]: #screenshot
[Configure]: #categories

